@@ -9,7 +9,7 @@ from watchgod import awatch
 from watchgod.watcher import Change
 
 from ntk.conf import (
-    Config, MEDIA_FILE_EXTENSIONS, GLOB_PATTERN, SASS_DESTINATION, SASS_SOURCE, SASS_DESTINATION_GLOB_PATTERN
+    Config, MEDIA_FILE_EXTENSIONS, GLOB_PATTERN, SASS_DESTINATION, SASS_SOURCE
 )
 from ntk.decorator import parser_config
 from ntk.gateway import Gateway
@@ -59,6 +59,10 @@ class Command:
         logging.info(f'[{self.config.env}] Connecting to {self.config.store}')
         logging.info(f'[{self.config.env}] Uploading {template_count} files to theme id {self.config.theme_id}')
 
+        for template_name in template_names:
+            if compile_sass and get_template_name(template_name).split('/')[0] == SASS_SOURCE:
+                self._compile_sass()
+
         for template_name in progress_bar(
                 template_names, prefix=f'[{self.config.env}] Progress:', suffix='Complete', length=50):
 
@@ -74,10 +78,6 @@ class Command:
                     content = f.read()
                     f.close()
 
-            paths = template_name.split('/')
-            if compile_sass and paths[0] == SASS_SOURCE:
-                self._compile_sass()
-
             self.gateway.create_or_update_template(
                 theme_id=self.config.theme_id, template_name=relative_pathfile, content=content, files=files)
 
@@ -134,14 +134,13 @@ class Command:
             self.gateway.delete_template(theme_id=self.config.theme_id, template_name=template_name)
 
     def _compile_sass(self):
-        logging.info(f'[{self.config.env}] Compile sass at directory: {SASS_SOURCE} to {SASS_DESTINATION}')
+        logging.info(f'[{self.config.env}] Processing {SASS_SOURCE} to {SASS_DESTINATION}.')
         try:
             sass.compile(dirname=(SASS_SOURCE, SASS_DESTINATION), output_style=self.config.sass_output_style)
-            for file in glob.glob(SASS_DESTINATION_GLOB_PATTERN, recursive=True):
-                logging.info(f'[{self.config.env}] Updated {file}')
-            logging.info(f'[{self.config.env}] Compile sass successfully.')
+            logging.info(f'[{self.config.env}] Sass successfully processed.')
         except Exception as error:
-            logging.error(f'[{self.config.env}] Compile sass failed with {error}')
+            logging.error(f'[{self.config.env}] Sass processing failed, see error below.')
+            logging.error(f'[{self.config.env}] {error}')
 
     @parser_config(theme_id_required=False)
     def init(self, parser):
@@ -197,7 +196,7 @@ class Command:
         loop = asyncio.get_event_loop()
         loop.run_until_complete(main())
 
-    @parser_config(write_file=True)
+    @parser_config()
     def compile_sass(self, parser):
-        logging.info(f'[{self.config.env}] Sass output style {self.config.sass_output_style}')
+        logging.info(f'[{self.config.env}] Sass output style {self.config.sass_output_style}.')
         self._compile_sass()
